@@ -8,6 +8,9 @@
 #include "gimmix-systray.h"
 #include "gimmix-playlist.h"
 
+/* Initialize all interface widgets */
+void gimmix_interface_widgets_init (void);
+
 /* Initializes default interface signals */
 void gimmix_init (void);
 
@@ -17,6 +20,12 @@ void gimmix_set_song_info (void);
 /* Toggles visibility of main window */
 void gimmix_window_visible_toggle (void);
 
+/* Disable widgets */
+void gimmix_interface_disable_controls (void);
+
+/* Enable widgets */
+void gimmix_interface_enable_controls (void);
+
 /* interface cleanup */
 void gimmix_interface_cleanup (void);
 
